@@ -1,6 +1,8 @@
 from .general_functions import *
 from .core import *
 from .load_files import *
+from .figlist import *
+from .nnls import *
 
 #import numpy
 
@@ -12,4 +14,4 @@ from .load_files import *
 #        'OLDplot',
 #        'nddata_hdf5']
 #__all__.extend(numpy.__all__)
-__all__ = filter(lambda x: x[0] != '_',dir())
+__all__ = [x for x in dir() if x[0] != '_']
