@@ -1,7 +1,27 @@
 from pylab import * 
 
 def convolve(self,axisname,filterwidth,convfunc = (lambda x,y: exp(-(x**2)/(2.0*(y**2))))):
-    r'''perform a normalized convolution'''
+    r'''Perform a convolution.
+    
+    Parameters
+    ==========
+
+    axisname: str
+        apply the convolution along `axisname`
+
+    filterwidth: double
+        width of the convolution function.
+
+    convfunc: function
+        A function that takes two arguments -- the first are the axis coordinates and the second is `filterwidth`.
+        Default is a normalized Gaussian of width (:math:`\sigma`)
+        `filterwidth`
+        :math:`\frac{1}{2 \sigma^2}\exp\left( - \frac{x^2}{2 \sigma^2} \right)`
+        For example if you want a complex lorentzian with `filterwidth` controlled by the rate $R$, 
+        *i.e.*
+        :math:`\frac{-1}{-i 2 \pi f - R}`
+        then ``convfunc = lambda f,R: -1./(-1j*2*pi*f-R)``
+    '''
     #{{{ make a version of x that is oriented along the correct dimension
     x = self.getaxis(axisname).copy()
     x_centerpoint = (x[-1]+x[0])/2
