@@ -1,4 +1,4 @@
-from pylab import *
+r'''The :class:`ndshape` class allows you to allocate arrays and determine the shape of existing arrays.'''
 from .general_functions import *
 
 class ndshape_base ():
@@ -48,8 +48,8 @@ class ndshape_base ():
                 if len(self.shape) == 0 and len(self.dimlabels) == 0:
                     self.zero_dimensional = True
                     return
-            elif type(args[0]) is list:
-                self.dimlabels, self.shape = map(list,zip(*args[0]))
+            elif isinstance(args[0], list):
+                self.dimlabels, self.shape = list(map(list,list(zip(*args[0]))))
             else:
                 raise ValueError('If you pass a single argument, it must be an nddata')
         return
@@ -82,11 +82,11 @@ class ndshape_base ():
         self.shape = [1] * len(addeddims) + list(self.shape)
         #}}}
         return self
-    def __add__(self,arg):
+    def __radd__(self,arg):
         'take list of shape,dimlabels'
         shape = arg[0]
         dimlabels = arg[1]
-        if type(shape) is str:
+        if isinstance(shape, str):
             shape,dimlabels = dimlabels,shape
         if isscalar(self.shape):
             self.shape = [self.shape]
@@ -99,12 +99,12 @@ class ndshape_base ():
         self.shape = shape + self.shape
         self.dimlabels = dimlabels + self.dimlabels
         return self
-    def add_correctly(self,arg):
+    def __add__(self,arg):
         '''take list of shape,dimlabels
         this is the correct function, until I can fix my back-references for add, which does it backwards'''
         shape = arg[0]
         dimlabels = arg[1]
-        if type(shape) is str:
+        if isinstance(shape, str):
             shape,dimlabels = dimlabels,shape
         if isscalar(self.shape):
             self.shape = [self.shape]
@@ -118,10 +118,10 @@ class ndshape_base ():
         self.dimlabels = self.dimlabels + dimlabels
         return self
     def __repr__(self): #how it responds to print
-        return zip(self.shape,self.dimlabels).__repr__()
+        return list(zip(self.shape,self.dimlabels)).__repr__()
     def __getitem__(self,args):
         try:
-            mydict = dict(zip(self.dimlabels,self.shape))
+            mydict = dict(list(zip(self.dimlabels,self.shape)))
         except Exception as e:
             raise ValueError(strm("either dimlabels=",self.dimlabels,"or shape",
                 self.shape,"not in the correct format") + explain_error(e))
@@ -129,6 +129,11 @@ class ndshape_base ():
             return mydict[args]
         except:
             raise ValueError(strm("one or more of the dimensions named",args,"do not exist in",self.dimlabels))
+    def rename(self,before,after):
+        r'rename a dimension'
+        thisindex = self.axn(before)
+        self.dimlabels[thisindex] = after
+        return self
     def pop(self,label):
         r'remove a dimension'
         thisindex = self.axn(label)
